SensorRateConfig

Struct SensorRateConfig 

pub struct SensorRateConfig {
    pub sampling_period_ns: Option<i64>,
    pub max_reporting_latency_ns: Option<i64>,
    /* private fields */
}
Rate configuration given to Driver::ConfigureSensorRate and Manager::ConfigureSensorRate.

Fields

sampling_period_ns: Option<i64>

The desired time period between samples arriving from the hardware.

Required.

max_reporting_latency_ns: Option<i64>

How long a sensor value may be buffered before it is emitted. A value of zero will result in no buffering.

Required.